pub(crate) trait ParamLike {
// Required methods
fn type_name(&self) -> &str;
fn name(&self) -> Option<&str>;
}Expand description
Helper trait to abstract over a type that can be documented as a parameter.
pub(crate) trait ParamLike {
// Required methods
fn type_name(&self) -> &str;
fn name(&self) -> Option<&str>;
}Helper trait to abstract over a type that can be documented as a parameter.